@@ -11,9 +11,6 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KDBusService>
 // Qt
 #include <QApplication>
@@ -21,18 +18,8 @@
 
 int main(int argc, char *argv[])
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("kbreakout"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kbreakoutrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("kbreakoutui.rc"));
-    migrate.migrate();
-#endif
     KLocalizedString::setApplicationDomain("kbreakout");
 
     KAboutData aboutData(QStringLiteral("kbreakout"), i18n("KBreakOut"), QStringLiteral(KBREAKOUT_VERSION_STRING));
@@ -57,7 +44,7 @@ int main(int argc, char *argv[])
     aboutData.addCredit(i18n("Viranch Mehta"),
                         i18n("port to QtQuick"),
                         QStringLiteral("viranch.mehta@gmail.com"));
-    aboutData.setHomepage(QStringLiteral("https://games.kde.org/kbreakout"));
+    aboutData.setHomepage(QStringLiteral("https://apps.kde.org/kbreakout"));
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
